==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ru.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "События",
    "Personal activity feed for %s" : "Персональная лента событий для %s",
    "Your feed URL is invalid" : "Ваша ссылка новостной ленты неправильная",
    "Your settings have been updated." : "Настройки обновлены.",
    "Mail" : "Почта",
    "Stream" : "Поток",
    "Activities" : "События",
    "Error loading activities" : "Ошибка загрузки событий",
    "No activities" : "Событий нет",
    "This stream will show events like additions, changes & shares" : "Этот поток будет отображать события вроде добавления, изменения файлов или открытия к ним доступа",
    "There are no events for this filter" : "Нет событий соответствующих фильтру",
    "Activity notification" : "Уведомление о событиях",
    "All Activities" : "Все действия",
    "Activities by you" : "Ваши действия",
    "Activities by others" : "Действия других пользователей",
    "\"remote user\"" : "\"удалённый пользователь\"",
    "in %s" : "в %s",
    "%s and %s" : "%s и %s",
    ", " : ",",
    "_%s and <strong %s>%n more</strong>_::_%s and <strong %s>%n more</strong>_" : ["%s и <strong %s>еще %n</strong>","%s и <strong %s>еще %n</strong>","%s и <strong %s>еще %n</strong>","%s и <strong %s>еще %n</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s и ещё %n","%s и ещё %n","%s и ещё %n","%s и ещё %n"],
    "Hello %s," : "Привет, %s,",
    "You are receiving this email because the following things happened at %s" : "Вы получили это электронное сообщение, потому что произошли следующие изменения %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "Notifications" : "Уведомления",
    "List your own actions in the stream" : "Показывать мои действия в потоке",
    "Notify about your own actions via email" : "Уведомлять о моих действиях по email",
    "You need to set up your email address before you can receive notification emails." : "Для получения уведомлений укажите свой e-mail в настройках.",
    "Send emails:" : "Отправлять электронные сообщения:",
    "Hourly" : "Ежечасно",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Activity feed" : "Лента событий",
    "Enable RSS feed" : "Включить RSS ленту",
    "No activity yet" : "Событий ещё нет",
    "No more events to load" : "Больше нет событий для загрузки",
    "Files" : "Файлы",
    "_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"has-tooltip\" title=\"%s\">%n more</strong>_" : ["%s и<strong class=\"has-tooltip\" title=\"%s\">еще %n</strong>","%s и<strong class=\"has-tooltip\" title=\"%s\">еще %n</strong>","%s и<strong class=\"has-tooltip\" title=\"%s\">еще %n</strong>","%s и<strong class=\"has-tooltip\" title=\"%s\">еще %n</strong>"]
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> owncloud-9.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/ru.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "События",
    "Activities" : "События",
    "Error loading activities" : "Ошибка загрузки событий",
    "No activities" : "Событий нет",
    "Load more activities" : "Загрузить больше мероприятий",
    ", " : ",",
    "{parameterList} and {lastParameter}" : "{parameterList} и {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} и {linkStart}еще %n{linkEnd}","{parameterList} и {linkStart}еще %n{linkEnd}","{parameterList} и {linkStart}еще %n{linkEnd}","{parameterList} и {linkStart}еще %n{linkEnd}"],
    "in {directory}" : "в {directory}",
    "This stream will show events like additions, changes & shares" : "Этот поток будет отображать события вроде добавления, изменения файлов или открытия к ним доступа",
    "There are no events for this filter" : "Нет событий соответствующих фильтру",
    "Today" : "Сегодня",
    "Yesterday" : "Вчера",
    "Personal activity feed for %s" : "Персональная лента событий для %s",
    "Your feed URL is invalid" : "Ваша ссылка новостной ленты неправильная",
    "Your settings have been updated." : "Настройки обновлены.",
    "Mail" : "Почта",
    "Stream" : "Поток",
    "\"remote user\"" : "\"удалённый пользователь\"",
    "Activity notification" : "Уведомление о событиях",
    "All Activities" : "Все действия",
    "Activities by you" : "Ваши действия",
    "Activities by others" : "Действия других пользователей",
    "%s and %s" : "%s и %s",
    "Hello %s," : "Привет, %s,",
    "You are receiving this email because the following things happened at %s" : "Вы получили это электронное сообщение, потому что произошли следующие события %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "List your own file actions in the stream" : "Список ваших собственных действий файлов в потоке",
    "Notify about your own actions via email" : "Уведомлять о моих действиях по email",
    "You need to set up your email address before you can receive notification emails." : "Для получения уведомлений укажите свой e-mail в настройках.",
    "Send emails:" : "Отправлять электронные сообщения:",
    "Hourly" : "Ежечасно",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Activity feed" : "Лента событий",
    "Enable RSS feed" : "Включить RSS ленту",
    "No activity yet" : "Событий ещё нет",
    "No more events to load" : "Больше нет событий для загрузки",
    "Files" : "Файлы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
